//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[CommonShantenArgs](index.md)/[bestShantenOnly](best-shanten-only.md)

# bestShantenOnly

[common]\
val [bestShantenOnly](best-shanten-only.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false

#### Parameters

common

| | |
|---|---|
| bestShantenOnly | 仅计算最优向听数的打法（不计算退向打法） |
